Adapter | Bioverse documentation

Skip to content

# Adapter

Adapters provide an interface to raw data repositories. They provide the download logic to place structure files and meta data to a local directory (`raw_path`). After download, they construct the initial `Data`-iterator, as well as `Split` and `Assets` objects. Usually, Adapters make use of a `Processor` to convert raw structure files to `Data` objects.

class bioverse.adapter.Adapter

  Bases: `ABC`

  abstract download(*args, **kwargs) → Tuple[Iterator[Batch], Split, Assets]

    Implement this method to download raw data from a repository and return the Batch-iterator, Split and Assets objects.